clear all; clc; close all
rng(100,'twister')
uqlab
%% measured data
% exp data
Y_expdata = myExpData();
myData.Name = 'Y';
myData.y = Y_expdata;
%% prior distribution
PriorOpts.Marginals(1).Name = 'meanE';
PriorOpts.Marginals(1).Type = 'Uniform';
PriorOpts.Marginals(1).Parameters = [0 100]*1e9;
% PriorOpts.Marginals(1).Bounds = [0 1000]*1e9;

PriorOpts.Marginals(2).Name = 'stdE';
PriorOpts.Marginals(2).Type = 'Uniform';
PriorOpts.Marginals(2).Parameters = [0 30]*1e9;
% PriorOpts.Marginals(2).Bounds = [0 200]*1e9;

PriorInput = uq_createInput(PriorOpts);
%% definition of the likelihood
myLogLike = @(params,y) custom_logLikePaper(params,y);
%% solver option
Solver.Type = 'MCMC';
Solver.MCMC.Sampler = 'MH';
Solver.MCMC.Steps = 5e3;
Solver.MCMC.NChains = 5;
Solver.MCMC.Proposal.PriorScale = 1e-3;
% Solver.MCMC.Proposal.Cov = diag([1e11 1e11]);
%% bayes analysis
BayesOpts.Type = 'inversion';
BayesOpts.Prior = PriorInput;
BayesOpts.Data = myData;
BayesOpts.LogLikelihood = myLogLike;
BayesOpts.Solver = Solver;
BayesAnalysis = uq_createAnalysis(BayesOpts);
%% postprocessing opts
uq_postProcessInversion(BayesAnalysis,'burnIn', 0.3...
    ,'gelmanRubin',1);
uq_print(BayesAnalysis)
uq_display(BayesAnalysis);
uq_display_uq_inversion_MCMC(BayesAnalysis, 'acceptance', 1);
PostSample3D = BayesAnalysis.Results.PostProc.PostSample ; 
PostSample2D = reshape(permute(PostSample3D, [2 1 3]), size(PostSample3D, 2), [])';
%% function
function Y = myExpData()
    m = 15e9; v = 3e9^2;
    L = 1;
    h = 0.1;
    b = 0.1;
    I = 1/12*b*h^3;
    F = 30e3;
    mu = log((m^2)/sqrt(v+m^2));
    sigma = sqrt(log(v/(m^2)+1));
    E = lognrnd(mu,sigma,[25,1]);
    disp = @(x) F.*x/2./(48*E*I).*(3*L^2-4*(x).^2);
    disp3points = [disp(0.25) disp(0.5) disp(0.75)];
    esplison = normrnd(0,0.1e-3,[25,3]);
    Y = disp3points+esplison;
end 